@@ -8,7 +8,7 @@ import os
 import sys
 import matplotlib.patches as patches
 class CalcPlot():
-    def __init__(self,mapping,chrom,start,end,threads=1,coverage=200,flag='None',chunksize=1000, fasta=None,style='classic',outlineoff=False):
+    def __init__(self,mapping,chrom,start,end,threads=1,coverage=200,flag='None',chunksize=1000, fasta=None,style='classic',outlineoff=False,clipped=1):
         self.mapping=mapping
         self.chrom=chrom
         self.start=start
@@ -30,8 +30,9 @@ class CalcPlot():
 
         else:
             config.read(os.path.join(os.path.dirname(__file__),'classic.ini'))
-
+        self.clipped=clipped
         colorDict={}
+
         for a in config['nucleotide color']:
             colorDict[a.upper()]=config['nucleotide color'][a]
             colorDict[a.lower()]=config['nucleotide color'][a]
@@ -39,80 +40,108 @@ class CalcPlot():
             colorDict[a]=config['special chars'][a]
         for a in config['MatplotStyle']:
             colorDict[a]=config['MatplotStyle'][a]
+        colorDict['ClippedAlpha']=float(config['clipped']['alpha'])
+        colorDict['ClippedBackground']=config['clipped']['background']
+        colorDict['ClippedColor']=config['clipped']['outline']
+
+        colorDict['OutlineAlpha']=float(config['outline']['alpha'])
+        colorDict['OutlineBackground']=config['outline']['background']
+        colorDict['OutlineColor']=config['outline']['outline']
+
+        colorDict['xticks']=config['Figure']['tickspacing']
+        
+
         self.colorDict=colorDict
         plt.style.use(self.colorDict['pltstyle'])
 
+        plt.rc('font', size=8)          # controls default text sizes
+        plt.rc('axes', titlesize=8)     # fontsize of the axes title
+        plt.rc('axes', labelsize=8)    # fontsize of the x and y labels
+        plt.rc('xtick', labelsize=6)    # fontsize of the tick labels
+        plt.rc('ytick', labelsize=6)    # fontsize of the tick labels
+        plt.rc('legend', fontsize=8)    # legend fontsize
+        plt.rc('figure', titlesize=8)  # fontsize of the figure title
+
+
 
         #self.colorDict={'A':'red','C':'blue','T':'green','G':'yellow','-':'white','N':'pink','a':'red','c':'blue','t':'green','g':'yellow','-':'white','n':'pink','|':'black'}
     def startPlot(self,cols,direction,schematic):
+        if self.end-self.start <=100:
+            self.Fontsize=self.Fontsize/2
+            x_perN=0.07/2
+            y_perN=0.12/2
+            self.LW=0.1
+            self.Fontsize=3
+            self.OutlineInnerW=2.2
+            self.OutlineOuterW=2.6
 
+
+
+        else:
+            x_perN=0.07
+            y_perN=0.12
+            self.LW=0.2
+            self.Fontsize=3*2
+            self.OutlineInnerW=2.2*2
+            self.OutlineOuterW=2.6*2
+
+        msize=.2
         self.cols=cols
         self.innerLW=0
-        self.LW=0.2
         if not direction and not schematic:
             if cols==1:
-                if self.end-self.start <=100:
-                    x=0.07*(self.end-self.start)
-                    y=0.12*self.maxHeight
-                    fig,ax=plt.subplots(1,cols,figsize=(x,y))
-                    self.Fontsize=6
-                    self.markersize=0.5
-                else:
-                    x=0.035*(self.end-self.start)
-                    y=0.06*self.maxHeight
-                    self.markersize=0.25
-
-                    fig,ax=plt.subplots(1,cols,figsize=(x,y))
+                x=x_perN*(self.end-self.start)
+                y=y_perN*self.maxHeight
+                self.markersize=msize
+                fig,ax=plt.subplots(1,cols,figsize=(x,y))
             if cols >1:
-                x=0.035*5000
-                y=0.06*self.maxHeight
+                x=x_perN*5000
+                y=y_perN*self.maxHeight
                 fig,ax=plt.subplots(1,cols,figsize=(x*cols,6))
         if direction and not schematic:
             if cols==1:
                 if self.end-self.start <=100:
-                    x=0.07*(self.end-self.start)
-                    y=0.12*self.maxHeight*2
-                    self.markersize=0.5
-
+                    x=x_perN*(self.end-self.start)
+                    y=y_perN*self.maxHeight*2
+                    self.markersize=msize
                     fig,ax=plt.subplots(2,cols,figsize=(x,y))
-                    self.Fontsize=6
                 else:
-                    x=0.035*(self.end-self.start)
-                    y=0.06*self.maxHeight*2
-                    self.markersize=0.25
+                    x=x_perN*(self.end-self.start)
+                    y=y_perN*self.maxHeight*2
+                    self.markersize=msize
                     fig,ax=plt.subplots(2,cols,figsize=(x,y))
             if cols >1:
-                x=0.035*5000
-                y=0.06*self.maxHeight*2
+                x=x_perN*5000
+                y=y_perN*self.maxHeight*2
                 fig,ax=plt.subplots(2,cols,figsize=(x*cols,6))
 
 
         if not direction and schematic:
             if self.cols >= 5:
-                y=(0.12*self.maxHeight)/5
+                y=(y_perN*self.maxHeight)/5
                 x=12
                 self.innerLW=0
                 self.LW=0.2
             else:
                 self.innerLW=0.4/self.cols
-                self.LW=3/self.cols
+                self.LW=2/self.cols
                 x=12
-                y=(0.12*self.maxHeight)/self.cols
+                y=(y_perN*self.maxHeight)/self.cols
             fig,ax=plt.subplots(1,self.cols,figsize=(x,y))
         if  direction and schematic:
             if self.cols >= 5:
-                y=((0.12*self.maxHeight)/5)*2
+                y=((y_perN*self.maxHeight)/5)*2
                 x=12
                 self.innerLW=0
                 self.LW=0.2
             else:
                 self.innerLW=0.4/self.cols
-                self.LW=3/self.cols
+                self.LW=2/self.cols
                 x=12
-                y=((0.12*self.maxHeight)/self.cols)*2
+                y=((y_perN*self.maxHeight)/self.cols)*2
             fig,ax=plt.subplots(2,self.cols,figsize=(x,y))
 
-        plt.suptitle('chromosome {} from {} to {}'.format(str(self.chrom),str(self.start),str(self.end)))
+        plt.suptitle('{} {}-{}'.format(str(self.chrom),str("{:,}".format(self.start)),str("{:,}".format(self.end))))
         self.ax=ax
         self.fig=fig
         plt.subplots_adjust(wspace=0,hspace=0.05, )
@@ -138,36 +167,77 @@ class CalcPlot():
 
 
 
+
+
+    def Xspacing(self,start,end,size=100,vcfPos=False):
+        if int(end-start)<size:
+            if not type(vcfPos)==int:
+                return [start,end]
+            else:
+                return [start,vcfPos,end]
+
+        digitDict={10:1,100:2,1000:3,10:1,10_000:4}
+        diffStart=size-int(str(start)[-1*digitDict[size]:])
+        rangeStart=start+diffStart
+        diffEnd=int(str(end)[-1*digitDict[size]:])
+        rangeEnd=end-diffEnd
+        x=size
+        if rangeEnd==end:
+            x=0
+        sizeChunks=list(range(rangeStart,rangeEnd+x,size))
+        chunks=[start]+sizeChunks+[end]
+        if type(vcfPos)==int:
+            print('here')
+            chunks=chunks+[vcfPos]
+            chunks.sort()
+        return chunks
+
+
+
     def AxSet(self,ax,start,end,chunk=False,direction='all',vcf=False):
+
         ylabel=direction
         if not chunk:
+            xlim=self.Xspacing(start,end,size=int(self.colorDict['xticks']))
             ax.set(xlim=(start,end),ylim=(0,self.maxHeight+2),ylabel=ylabel)
+            ax.yaxis.set_ticks_position('left')
+
             if vcf:
-                ax.set_xticks([start,start+(end-start)/2,end],)
-                ax.set_xticklabels([str("{:,}".format(start))+'vcf position',str("{:,}".format(end))+, rotation=40, ha='right')
+                xlim=self.Xspacing(start,end,size=int(self.colorDict['xticks']),vcfPos=int(start+(end-start)/2))
+                ax.set_xticks(xlim)
+                xlimStr=[str("{:,}".format(x)) for x in xlim]
+                ax.set_xticklabels(xlimStr, rotation=40, ha='right')
             else:
-                ax.set_xticklabels([str("{:,}".format(start))+str("{:,}".format(end))+, rotation=40, ha='right')
-                ax.set_xticks([start,end],)
+                xlim=self.Xspacing(start,end,size=int(self.colorDict['xticks']))
+                ax.set_xticks(xlim)
+                xlimStr=[str("{:,}".format(x)) for x in xlim]
+                ax.set_xticklabels(xlimStr, rotation=40, ha='right')
 
         else:
+            ax.xaxis.set_tick_params(length=1)
             ax.get_yaxis().set_visible(False)
+            xlim=self.Xspacing(start,start+self.chunksize,size=int(self.colorDict['xticks']))
+            xlimStr=[str("{:,}".format(x)) for x in xlim]
             ax.set(xlim=(start,start+self.chunksize),ylim=(0,self.maxHeight+2))
+            ax.yaxis.set_ticks_position('none')
+            ax.xaxis.set_ticks_position('bottom')
             if start==self.start:
                 ax.set(ylabel=ylabel)
                 ax.get_yaxis().set_visible(True)
-                ax.set_xticks([start])
-                ax.set_xticklabels([str("{:,}".format(start))+, rotation=40, ha='right',fontsize=6)
+                ax.set_xticks(xlim[:-1])
+                ax.set_xticklabels(xlimStr[:-1], rotation=40, ha='right')
             if end==self.end:
-                ax.set_xticks([start,start+self.chunksize])
-                ax.set_xticklabels(['',str((start+self.chunksize)/1_000_000)+, rotation=40, ha='right',fontsize=6)
+                ax.set_xticks(xlim[1:])
+                ax.set_xticklabels(xlimStr[1:], rotation=40, ha='right')
             if  start!=self.start and end!=self.end:
-                ax.set_xticks([start])
-                ax.set_xticklabels([''], rotation=40, ha='right',fontsize=6)
+                ax.set_xticks(xlim[1:-1])
+                ax.set_xticklabels(xlimStr[1:-1], rotation=40, ha='right')
 
 
         ax.spines['right'].set_visible(False)
         ax.spines['left'].set_visible(False)
 
+
     def CigChunker(self,cig):
         cigL=[]
         def parseCig(cig):
@@ -238,23 +308,23 @@ class CalcPlot():
 
 
             softClipp=len(chunk_cigarstringS)/chunkL
-            alpha=1
-            if flag=='None':
-                alpha=1
-            if flag=='MateUnmapped':
-                if mate:
-                    alpha=0.3
-            if flag=='SoftClipped':
-                if softClipp>=0.05:
-                    alpha=0.3
-            if flag=='MateUnmappedSoftClipped':
-                if softClipp>=0.1 or mate:
-                    alpha=0.3
+
+            alpha=self.colorDict['OutlineAlpha']
+            outlineColor=self.colorDict['OutlineColor']
+            outlineBackground=self.colorDict['OutlineBackground']
+
+            if softClipp >= self.clipped:
+                alpha=self.colorDict['ClippedAlpha']
+                outlineColor=self.colorDict['ClippedColor']
+                outlineBackground=self.colorDict['ClippedBackground']
+
+
+
             fastapos=0
             drawChunk=[]
             if not self.outlineoff:
-                ax.plot((s,s+len(query_alignment_sequence)-1),(y,y),color='black',linewidth=2.6,zorder=0)
-                ax.plot((s+0.1,s+len(query_alignment_sequence)-1-0.1),(y,y),color='darkgrey',linewidth=2.2,alpha=0.5,zorder=0)
+                ax.plot((s,s+len(query_alignment_sequence)-1),(y,y),color=outlineColor,linewidth=self.OutlineOuterW,zorder=0)
+                ax.plot((s+0.1,s+len(query_alignment_sequence)-1-0.1),(y,y),color=outlineBackground,linewidth=self.OutlineInnerW,alpha=alpha,zorder=0)
 
             fontDict={'A':r'$\mathtt{A}$','C':r'$\mathtt{C}$','G':r'$\mathtt{G}$','T':r'$\mathtt{T}$','-':r'$\mathtt{-}$'}
             xs=[x+s for x in range(0,len(chunk_cigarstring))]
@@ -267,7 +337,7 @@ class CalcPlot():
                 continue
 
             if self.fasta != 'None':
-                ax.scatter([x+s for x in range(0,len(chunk_cigarstring))],len(chunk_cigarstring)*[y], marker='o',s=self.markersize,color=self.colorDict['dot'],alpha=alpha)
+                ax.scatter([x+s for x in range(0,len(chunk_cigarstring))],len(chunk_cigarstring)*[y], marker='.',s=.2,linewidth=self.LW,color=self.colorDict['dot'],alpha=alpha)
 
             for p,alignPos in enumerate(chunk_cigarstring):
                 x=s+p
